# Changelog

## 0.1.0-alpha.39 (2024-11-22)

Full Changelog: [v0.1.0-alpha.38...v0.1.0-alpha.39](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.38...v0.1.0-alpha.39)

### Features

* **api:** api update ([#318](https://github.com/conductor-is/conductor-python/issues/318)) ([5e889b7](https://github.com/conductor-is/conductor-python/commit/5e889b7455340941804f0c2c0a4d83e43edb5841))


### Chores

* **internal:** fix compat model_dump method when warnings are passed ([#316](https://github.com/conductor-is/conductor-python/issues/316)) ([41bf269](https://github.com/conductor-is/conductor-python/commit/41bf269f99c5b036337e00176218920d88a9c850))

## 0.1.0-alpha.38 (2024-11-22)

Full Changelog: [v0.1.0-alpha.37...v0.1.0-alpha.38](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.37...v0.1.0-alpha.38)

### Features

* **api:** api update ([#313](https://github.com/conductor-is/conductor-python/issues/313)) ([7715330](https://github.com/conductor-is/conductor-python/commit/771533040af692733227179b45b69b0fefc6bca0))

## 0.1.0-alpha.37 (2024-11-22)

Full Changelog: [v0.1.0-alpha.36...v0.1.0-alpha.37](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.36...v0.1.0-alpha.37)

### Features

* **api:** api update ([#307](https://github.com/conductor-is/conductor-python/issues/307)) ([66afe6e](https://github.com/conductor-is/conductor-python/commit/66afe6e0a5a441dcecdbc6e819e93239d4a20725))
* **api:** api update ([#310](https://github.com/conductor-is/conductor-python/issues/310)) ([b34f9b0](https://github.com/conductor-is/conductor-python/commit/b34f9b0ac9c2f3dedee26ea20e042d44def7c15f))
* **api:** api update ([#311](https://github.com/conductor-is/conductor-python/issues/311)) ([14097ed](https://github.com/conductor-is/conductor-python/commit/14097edb9a25ea18540306c01f889828ba2303d6))


### Chores

* rebuild project due to codegen change ([#309](https://github.com/conductor-is/conductor-python/issues/309)) ([d7a932d](https://github.com/conductor-is/conductor-python/commit/d7a932d06403c0fdacd6a47cb6f9475c29d4c0f1))

## 0.1.0-alpha.36 (2024-11-17)

Full Changelog: [v0.1.0-alpha.35...v0.1.0-alpha.36](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.35...v0.1.0-alpha.36)

### Features

* **api:** api update ([#303](https://github.com/conductor-is/conductor-python/issues/303)) ([fb72473](https://github.com/conductor-is/conductor-python/commit/fb72473d9be51e41785acec48c5e1a293b0f4643))
* **api:** api update ([#305](https://github.com/conductor-is/conductor-python/issues/305)) ([07104f2](https://github.com/conductor-is/conductor-python/commit/07104f2383a6c7a67270651e42273394629cfaa5))
* **api:** api update ([#306](https://github.com/conductor-is/conductor-python/issues/306)) ([3016465](https://github.com/conductor-is/conductor-python/commit/301646549a68c9f325eed3dca56ae1ce9a88aed3))

## 0.1.0-alpha.35 (2024-11-17)

Full Changelog: [v0.1.0-alpha.34...v0.1.0-alpha.35](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.34...v0.1.0-alpha.35)

### Features

* **api:** api update ([#294](https://github.com/conductor-is/conductor-python/issues/294)) ([3f10892](https://github.com/conductor-is/conductor-python/commit/3f1089254a6680b1b0ee1f2aa0f53035efdb3872))
* **api:** api update ([#296](https://github.com/conductor-is/conductor-python/issues/296)) ([35bd17e](https://github.com/conductor-is/conductor-python/commit/35bd17e13b0e6f9a0bd6e92dc356da74f000e0f8))
* **api:** api update ([#297](https://github.com/conductor-is/conductor-python/issues/297)) ([1765972](https://github.com/conductor-is/conductor-python/commit/17659721ae55807c4ea1b134922d97f87e0409e7))
* **api:** api update ([#298](https://github.com/conductor-is/conductor-python/issues/298)) ([26b888b](https://github.com/conductor-is/conductor-python/commit/26b888bf5fdf0cee5e0463a0103e252fd98dd4e0))
* **api:** api update ([#299](https://github.com/conductor-is/conductor-python/issues/299)) ([26235d6](https://github.com/conductor-is/conductor-python/commit/26235d6a87abaf96f2d6347d4013d7884b106218))
* **api:** api update ([#300](https://github.com/conductor-is/conductor-python/issues/300)) ([9934816](https://github.com/conductor-is/conductor-python/commit/9934816306db035c00aac725f21011f385b78e84))
* **api:** manual updates ([#301](https://github.com/conductor-is/conductor-python/issues/301)) ([4a61f9c](https://github.com/conductor-is/conductor-python/commit/4a61f9cf932f632766f2590029f9a35669e3bad8))

## 0.1.0-alpha.34 (2024-11-14)

Full Changelog: [v0.1.0-alpha.33...v0.1.0-alpha.34](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.33...v0.1.0-alpha.34)

### Features

* **api:** api update ([#287](https://github.com/conductor-is/conductor-python/issues/287)) ([da64f61](https://github.com/conductor-is/conductor-python/commit/da64f613d07d596abd5e3ba0d3d2a0e0f5c40c79))
* **api:** api update ([#289](https://github.com/conductor-is/conductor-python/issues/289)) ([c6f58e7](https://github.com/conductor-is/conductor-python/commit/c6f58e78ff81a2816c73717493af1849008b70cb))
* **api:** api update ([#290](https://github.com/conductor-is/conductor-python/issues/290)) ([0a34b7a](https://github.com/conductor-is/conductor-python/commit/0a34b7a2aa974f504ea65ab19992440505789ede))
* **api:** api update ([#291](https://github.com/conductor-is/conductor-python/issues/291)) ([e371300](https://github.com/conductor-is/conductor-python/commit/e3713007f4f90e6b51385ed94b57877f864ace59))


### Styles

* **api:** reorder props ([#292](https://github.com/conductor-is/conductor-python/issues/292)) ([fbb2119](https://github.com/conductor-is/conductor-python/commit/fbb2119b07d0578518298a6bf1f752540484a276))

## 0.1.0-alpha.33 (2024-11-13)

Full Changelog: [v0.1.0-alpha.32...v0.1.0-alpha.33](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.32...v0.1.0-alpha.33)

### Features

* **api:** api update ([#280](https://github.com/conductor-is/conductor-python/issues/280)) ([99817d4](https://github.com/conductor-is/conductor-python/commit/99817d4b420146425304f46ddcd6277543fea64a))
* **api:** api update ([#282](https://github.com/conductor-is/conductor-python/issues/282)) ([4915327](https://github.com/conductor-is/conductor-python/commit/49153277d9a1e9c77ae5c723c8e9c9d5da4f56ff))
* **api:** api update ([#283](https://github.com/conductor-is/conductor-python/issues/283)) ([3f83852](https://github.com/conductor-is/conductor-python/commit/3f83852c3d6b54cbaddae4993c4c30c8d39ee105))
* **api:** api update ([#284](https://github.com/conductor-is/conductor-python/issues/284)) ([2809946](https://github.com/conductor-is/conductor-python/commit/2809946a1bce219eecc73677db5490e5151eee8b))
* **api:** api update ([#285](https://github.com/conductor-is/conductor-python/issues/285)) ([23c24f7](https://github.com/conductor-is/conductor-python/commit/23c24f7526bf11f7cc7d8bfaf1debf2cb848480f))

## 0.1.0-alpha.32 (2024-11-13)

Full Changelog: [v0.1.0-alpha.31...v0.1.0-alpha.32](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.31...v0.1.0-alpha.32)

### Styles

* **api:** reorder resource and method keys in config ([#277](https://github.com/conductor-is/conductor-python/issues/277)) ([45afd70](https://github.com/conductor-is/conductor-python/commit/45afd70fc57e03401cb0b2c9cd505823bc18dac1))

## 0.1.0-alpha.31 (2024-11-13)

Full Changelog: [v0.1.0-alpha.30...v0.1.0-alpha.31](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.30...v0.1.0-alpha.31)

### Features

* **api:** api update ([#274](https://github.com/conductor-is/conductor-python/issues/274)) ([7c8a091](https://github.com/conductor-is/conductor-python/commit/7c8a091ef86fb7566930ffcfe3059b7fedeec9bd))

## 0.1.0-alpha.30 (2024-11-13)

Full Changelog: [v0.1.0-alpha.29...v0.1.0-alpha.30](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.29...v0.1.0-alpha.30)

### Features

* **api:** api update ([#252](https://github.com/conductor-is/conductor-python/issues/252)) ([11c9b2e](https://github.com/conductor-is/conductor-python/commit/11c9b2ecf0d31d0dce305414452dd2d1a93b92b6))
* **api:** api update ([#253](https://github.com/conductor-is/conductor-python/issues/253)) ([56795a6](https://github.com/conductor-is/conductor-python/commit/56795a63212b51a1740b1476af5517fff7af0227))
* **api:** api update ([#254](https://github.com/conductor-is/conductor-python/issues/254)) ([d38487d](https://github.com/conductor-is/conductor-python/commit/d38487dbc0d56c3fb99d50a1789b6add73479c81))
* **api:** api update ([#255](https://github.com/conductor-is/conductor-python/issues/255)) ([29b6c46](https://github.com/conductor-is/conductor-python/commit/29b6c46815baca4d89d788b5cd141849e53024e9))
* **api:** api update ([#256](https://github.com/conductor-is/conductor-python/issues/256)) ([6a976f3](https://github.com/conductor-is/conductor-python/commit/6a976f35361f9e0f7e76397be26f65f83f4ff818))
* **api:** api update ([#258](https://github.com/conductor-is/conductor-python/issues/258)) ([4b20a25](https://github.com/conductor-is/conductor-python/commit/4b20a25cf5726726dea00746669a180da69c2308))
* **api:** api update ([#259](https://github.com/conductor-is/conductor-python/issues/259)) ([0c54a19](https://github.com/conductor-is/conductor-python/commit/0c54a19858d1144d5029b0055a099ac6bf1d9f34))
* **api:** api update ([#261](https://github.com/conductor-is/conductor-python/issues/261)) ([cd6abe3](https://github.com/conductor-is/conductor-python/commit/cd6abe3a48a8af3bb81f39ea476cf80c888ec119))
* **api:** api update ([#262](https://github.com/conductor-is/conductor-python/issues/262)) ([3da684c](https://github.com/conductor-is/conductor-python/commit/3da684c41751d12fc321a8050095aa1403df46c7))
* **api:** api update ([#263](https://github.com/conductor-is/conductor-python/issues/263)) ([877cceb](https://github.com/conductor-is/conductor-python/commit/877ccebe4e9e0a550bc8c76e6cccd44480bad7c9))
* **api:** api update ([#264](https://github.com/conductor-is/conductor-python/issues/264)) ([1cba4c9](https://github.com/conductor-is/conductor-python/commit/1cba4c9333440c0bdfc7f98a8b27010e7eee6231))
* **api:** api update ([#265](https://github.com/conductor-is/conductor-python/issues/265)) ([47f840d](https://github.com/conductor-is/conductor-python/commit/47f840d5f762b0cd065f7ea49182e73c74294297))
* **api:** api update ([#266](https://github.com/conductor-is/conductor-python/issues/266)) ([d724371](https://github.com/conductor-is/conductor-python/commit/d724371a7b10006750fa8fdf66ec32b07909bba3))
* **api:** api update ([#267](https://github.com/conductor-is/conductor-python/issues/267)) ([fb907df](https://github.com/conductor-is/conductor-python/commit/fb907df98b657b5f3e077355a632268b53fe3bc3))
* **api:** api update ([#268](https://github.com/conductor-is/conductor-python/issues/268)) ([5d6dd29](https://github.com/conductor-is/conductor-python/commit/5d6dd29ddaea2c4f58cb19f38f9b2dbfb960e8f3))
* **api:** api update ([#269](https://github.com/conductor-is/conductor-python/issues/269)) ([a564380](https://github.com/conductor-is/conductor-python/commit/a56438021b71c69cabfbcd9cf37fe40d0816e9e4))
* **api:** api update ([#270](https://github.com/conductor-is/conductor-python/issues/270)) ([c3664b0](https://github.com/conductor-is/conductor-python/commit/c3664b0bfd7b5e4d5cfb90d8205633bf3ec58e48))
* **api:** api update ([#272](https://github.com/conductor-is/conductor-python/issues/272)) ([7321711](https://github.com/conductor-is/conductor-python/commit/7321711ebbcae657a2d0f6ff67886c45ea9638bf))


### Chores

* rebuild project due to codegen change ([#250](https://github.com/conductor-is/conductor-python/issues/250)) ([ac2690e](https://github.com/conductor-is/conductor-python/commit/ac2690e8c1d35a931365cf4dcd5d6a25d6ad917a))
* rebuild project due to codegen change ([#257](https://github.com/conductor-is/conductor-python/issues/257)) ([b45caaa](https://github.com/conductor-is/conductor-python/commit/b45caaa2d2471df36b56d4b31140d33edf7d51bd))
* rebuild project due to codegen change ([#260](https://github.com/conductor-is/conductor-python/issues/260)) ([fa457e0](https://github.com/conductor-is/conductor-python/commit/fa457e01cec6d9c5aa98d59c7e06c55296b005ff))

## 0.1.0-alpha.29 (2024-11-11)

Full Changelog: [v0.1.0-alpha.28...v0.1.0-alpha.29](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.28...v0.1.0-alpha.29)

### Features

* **api:** api update ([#246](https://github.com/conductor-is/conductor-python/issues/246)) ([a3821f7](https://github.com/conductor-is/conductor-python/commit/a3821f7cdb5ec01a8dd57e3f5fcdf9885ef2fca5))


### Chores

* rebuild project due to codegen change ([#248](https://github.com/conductor-is/conductor-python/issues/248)) ([bd96d6a](https://github.com/conductor-is/conductor-python/commit/bd96d6abe924bc614bf20260692b3a907cf8e8c0))

## 0.1.0-alpha.28 (2024-11-08)

Full Changelog: [v0.1.0-alpha.27...v0.1.0-alpha.28](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.27...v0.1.0-alpha.28)

### Features

* **api:** api update ([#241](https://github.com/conductor-is/conductor-python/issues/241)) ([bd8bf90](https://github.com/conductor-is/conductor-python/commit/bd8bf904dd111630152172979725673df3668992))
* **api:** api update ([#244](https://github.com/conductor-is/conductor-python/issues/244)) ([5981b44](https://github.com/conductor-is/conductor-python/commit/5981b44b69d19e672ee77c8dd023f55115e2254c))


### Chores

* rebuild project due to codegen change ([#243](https://github.com/conductor-is/conductor-python/issues/243)) ([33b9a3d](https://github.com/conductor-is/conductor-python/commit/33b9a3daaa275a957f3fbd1a8d5215844a52b2f1))

## 0.1.0-alpha.27 (2024-11-05)

Full Changelog: [v0.1.0-alpha.26...v0.1.0-alpha.27](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.26...v0.1.0-alpha.27)

### Features

* **api:** api update ([#230](https://github.com/conductor-is/conductor-python/issues/230)) ([e339794](https://github.com/conductor-is/conductor-python/commit/e339794d5e43d47a259463ab86c28db1bbe03744))
* **api:** api update ([#232](https://github.com/conductor-is/conductor-python/issues/232)) ([66adc05](https://github.com/conductor-is/conductor-python/commit/66adc0587d8f0b3665153aaef75a0662dbea7d8c))
* **api:** api update ([#233](https://github.com/conductor-is/conductor-python/issues/233)) ([96d6201](https://github.com/conductor-is/conductor-python/commit/96d62011782a65db5747c43adba52b9b1d369e3b))
* **api:** api update ([#234](https://github.com/conductor-is/conductor-python/issues/234)) ([518f06a](https://github.com/conductor-is/conductor-python/commit/518f06ac0bf0c4f0b0d06bde7a73f412bd16010e))
* **api:** api update ([#236](https://github.com/conductor-is/conductor-python/issues/236)) ([cf93450](https://github.com/conductor-is/conductor-python/commit/cf934502b6c9ab26ade073191d55a7075408693d))
* **api:** api update ([#237](https://github.com/conductor-is/conductor-python/issues/237)) ([e808673](https://github.com/conductor-is/conductor-python/commit/e808673c7b00ef401a66677e9343132bd7fc4c6f))
* **api:** api update ([#239](https://github.com/conductor-is/conductor-python/issues/239)) ([1b8d8e8](https://github.com/conductor-is/conductor-python/commit/1b8d8e8325fa78d8b72f91addfae1ecb2ca247c2))
* **api:** manual updates ([#235](https://github.com/conductor-is/conductor-python/issues/235)) ([84b7a95](https://github.com/conductor-is/conductor-python/commit/84b7a954fd1575d9c46fb1886d4b68f310f71796))


### Refactors

* **api:** Fix check model name ([#238](https://github.com/conductor-is/conductor-python/issues/238)) ([d561a8b](https://github.com/conductor-is/conductor-python/commit/d561a8b9d5572370d8e46d91d9f5df57936d0164))

## 0.1.0-alpha.26 (2024-11-04)

Full Changelog: [v0.1.0-alpha.25...v0.1.0-alpha.26](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.25...v0.1.0-alpha.26)

### Features

* **api:** api update ([#221](https://github.com/conductor-is/conductor-python/issues/221)) ([d93e2e4](https://github.com/conductor-is/conductor-python/commit/d93e2e492dc317399c9dcf3c741bf111dbb3f1ab))
* **api:** api update ([#223](https://github.com/conductor-is/conductor-python/issues/223)) ([4c0ba46](https://github.com/conductor-is/conductor-python/commit/4c0ba46f2a933bcd33e0c0cd6291a4e59da5439a))
* **api:** api update ([#224](https://github.com/conductor-is/conductor-python/issues/224)) ([706ca7e](https://github.com/conductor-is/conductor-python/commit/706ca7e29a6d5e5f0f23a375cbc3a6239662b77b))
* **api:** api update ([#225](https://github.com/conductor-is/conductor-python/issues/225)) ([66767b2](https://github.com/conductor-is/conductor-python/commit/66767b2a9b803236f8c8160c193fd1a49042b357))
* **api:** api update ([#226](https://github.com/conductor-is/conductor-python/issues/226)) ([6d80050](https://github.com/conductor-is/conductor-python/commit/6d800507fe2ecb410ade2d0bec1a90d794dab43b))
* **api:** api update ([#227](https://github.com/conductor-is/conductor-python/issues/227)) ([50bb1d3](https://github.com/conductor-is/conductor-python/commit/50bb1d37416ac98b975e3cb38babe103dc036441))
* **api:** api update ([#228](https://github.com/conductor-is/conductor-python/issues/228)) ([e5a3752](https://github.com/conductor-is/conductor-python/commit/e5a3752327c2e0b33df5208005697d2f609fa147))

## 0.1.0-alpha.25 (2024-11-04)

Full Changelog: [v0.1.0-alpha.24...v0.1.0-alpha.25](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.24...v0.1.0-alpha.25)

### Features

* **api:** api update ([#211](https://github.com/conductor-is/conductor-python/issues/211)) ([e3f9f35](https://github.com/conductor-is/conductor-python/commit/e3f9f3585e57454d698e1bc5d953bd1a4f979d04))
* **api:** api update ([#213](https://github.com/conductor-is/conductor-python/issues/213)) ([91698c3](https://github.com/conductor-is/conductor-python/commit/91698c33a294cbec58a38730d7c219b5a0371db9))
* **api:** api update ([#215](https://github.com/conductor-is/conductor-python/issues/215)) ([c089b11](https://github.com/conductor-is/conductor-python/commit/c089b11fb4e65bcec6ff96cc6c5dc037cc7abe36))
* **api:** api update ([#216](https://github.com/conductor-is/conductor-python/issues/216)) ([c1816ec](https://github.com/conductor-is/conductor-python/commit/c1816ec032ab15a339d1aac16a83a5a5ad33df9c))
* **api:** api update ([#217](https://github.com/conductor-is/conductor-python/issues/217)) ([b326e2a](https://github.com/conductor-is/conductor-python/commit/b326e2adcdc619aa619303d209528303a07833f8))
* **api:** api update ([#218](https://github.com/conductor-is/conductor-python/issues/218)) ([74fb7c9](https://github.com/conductor-is/conductor-python/commit/74fb7c9e0b6af6cc8e0bb0f1f2db53fbef0448c0))
* **api:** api update ([#219](https://github.com/conductor-is/conductor-python/issues/219)) ([993490d](https://github.com/conductor-is/conductor-python/commit/993490db8e0b161238e30487a885298a5044bfe3))
* **api:** manual updates ([#214](https://github.com/conductor-is/conductor-python/issues/214)) ([3a6122b](https://github.com/conductor-is/conductor-python/commit/3a6122b66be72cb3742b4b1252dbf5a2f914cd33))

## 0.1.0-alpha.24 (2024-11-03)

Full Changelog: [v0.1.0-alpha.23...v0.1.0-alpha.24](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.23...v0.1.0-alpha.24)

### Features

* **api:** api update ([#203](https://github.com/conductor-is/conductor-python/issues/203)) ([ef9dd64](https://github.com/conductor-is/conductor-python/commit/ef9dd6416466f02010e386cff256fc866cd65e8a))
* **api:** api update ([#204](https://github.com/conductor-is/conductor-python/issues/204)) ([b654f04](https://github.com/conductor-is/conductor-python/commit/b654f0494c46407ab22224914b45c0fa39fda275))
* **api:** api update ([#205](https://github.com/conductor-is/conductor-python/issues/205)) ([4dd494b](https://github.com/conductor-is/conductor-python/commit/4dd494b4c5be748476335d8c10829aaed8dd2ee7))
* **api:** api update ([#206](https://github.com/conductor-is/conductor-python/issues/206)) ([c2c1d44](https://github.com/conductor-is/conductor-python/commit/c2c1d44d49f838c5277b01eda3bf537150e22850))
* **api:** api update ([#207](https://github.com/conductor-is/conductor-python/issues/207)) ([38dfebe](https://github.com/conductor-is/conductor-python/commit/38dfebe82f95a2932ad8b4b675e5dae62f2c8d2d))
* **api:** api update ([#208](https://github.com/conductor-is/conductor-python/issues/208)) ([e2b70ee](https://github.com/conductor-is/conductor-python/commit/e2b70ee0370d15df9d2f719990f1fdd4734b3b04))
* **api:** api update ([#209](https://github.com/conductor-is/conductor-python/issues/209)) ([154ef1c](https://github.com/conductor-is/conductor-python/commit/154ef1c8a3623ad6d4ec31e54fe238597f902ba3))
* **api:** manual updates ([#201](https://github.com/conductor-is/conductor-python/issues/201)) ([6067c05](https://github.com/conductor-is/conductor-python/commit/6067c05bfeec08288babfdf233e6284c63e23e7d))

## 0.1.0-alpha.23 (2024-11-01)

Full Changelog: [v0.1.0-alpha.22...v0.1.0-alpha.23](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.22...v0.1.0-alpha.23)

### Features

* **api:** api update ([#198](https://github.com/conductor-is/conductor-python/issues/198)) ([f4bfb1a](https://github.com/conductor-is/conductor-python/commit/f4bfb1a3b049c5f20978dcc1086acb969092fc20))
* **api:** api update ([#199](https://github.com/conductor-is/conductor-python/issues/199)) ([c55c61a](https://github.com/conductor-is/conductor-python/commit/c55c61aec269dd6ae1ac3e685133b90e0dc2599b))
* **api:** manual updates ([#195](https://github.com/conductor-is/conductor-python/issues/195)) ([aab7f65](https://github.com/conductor-is/conductor-python/commit/aab7f65cdef91a085a2ee9f7795fd08f4b6c9750))

## 0.1.0-alpha.22 (2024-10-31)

Full Changelog: [v0.1.0-alpha.21...v0.1.0-alpha.22](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.21...v0.1.0-alpha.22)

### Features

* **api:** api update ([#182](https://github.com/conductor-is/conductor-python/issues/182)) ([f5af503](https://github.com/conductor-is/conductor-python/commit/f5af50396a56d73fcdf1c05edcda8692a52ce915))
* **api:** api update ([#184](https://github.com/conductor-is/conductor-python/issues/184)) ([337f53d](https://github.com/conductor-is/conductor-python/commit/337f53db91f83ddc07cc5c079fca9ea469740628))
* **api:** api update ([#186](https://github.com/conductor-is/conductor-python/issues/186)) ([028b0cd](https://github.com/conductor-is/conductor-python/commit/028b0cd920755d690c7f4fcc1cf82937245d9dec))
* **api:** api update ([#187](https://github.com/conductor-is/conductor-python/issues/187)) ([ca329b6](https://github.com/conductor-is/conductor-python/commit/ca329b631faa671bfc56eefe4c2999eb6dface05))
* **api:** api update ([#189](https://github.com/conductor-is/conductor-python/issues/189)) ([3c8a4cb](https://github.com/conductor-is/conductor-python/commit/3c8a4cb73445a6552cf74c10f29b81853bf4f3f5))
* **api:** api update ([#192](https://github.com/conductor-is/conductor-python/issues/192)) ([92c6f6b](https://github.com/conductor-is/conductor-python/commit/92c6f6ba3ab35f82857a04d797bc49970b6b5c59))
* **api:** api update ([#194](https://github.com/conductor-is/conductor-python/issues/194)) ([fe40e44](https://github.com/conductor-is/conductor-python/commit/fe40e4428631f1647290d593c4e02c16a543ba84))
* **api:** manual updates ([#185](https://github.com/conductor-is/conductor-python/issues/185)) ([18336f6](https://github.com/conductor-is/conductor-python/commit/18336f654eef1d1c3c8fb066afb7aeb3097a7edd))
* **api:** manual updates ([#188](https://github.com/conductor-is/conductor-python/issues/188)) ([7d308c0](https://github.com/conductor-is/conductor-python/commit/7d308c06850d74816bb39b0d538c5e532f064e33))
* **api:** remove integration connections ([#190](https://github.com/conductor-is/conductor-python/issues/190)) ([77daf23](https://github.com/conductor-is/conductor-python/commit/77daf233bc5270824bd1fa479293f6a5a830e08f))


### Bug Fixes

* **internal:** remove integration connections ([4d0aee7](https://github.com/conductor-is/conductor-python/commit/4d0aee7016022c4c19b95220a7a38b701fcbdb65))


### Chores

* codegen changes ([#193](https://github.com/conductor-is/conductor-python/issues/193)) ([9e6f9bf](https://github.com/conductor-is/conductor-python/commit/9e6f9bf4f9775636c362b730ed759c578fe9f152))

## 0.1.0-alpha.21 (2024-10-30)

Full Changelog: [v0.1.0-alpha.20...v0.1.0-alpha.21](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.20...v0.1.0-alpha.21)

### Features

* **api:** api update ([#171](https://github.com/conductor-is/conductor-python/issues/171)) ([45c98a0](https://github.com/conductor-is/conductor-python/commit/45c98a0e1beb6ada649e77ac8c14fbada2258a99))
* **api:** api update ([#173](https://github.com/conductor-is/conductor-python/issues/173)) ([555ab6d](https://github.com/conductor-is/conductor-python/commit/555ab6dc99f9bb32f91d605b66936efe02839299))
* **api:** api update ([#174](https://github.com/conductor-is/conductor-python/issues/174)) ([0d53716](https://github.com/conductor-is/conductor-python/commit/0d5371650ce91a7291f97f419015219fc58d39a1))
* **api:** api update ([#175](https://github.com/conductor-is/conductor-python/issues/175)) ([df3269d](https://github.com/conductor-is/conductor-python/commit/df3269dd05135330843a79474b6afb347d0e3672))
* **api:** api update ([#176](https://github.com/conductor-is/conductor-python/issues/176)) ([4f7523d](https://github.com/conductor-is/conductor-python/commit/4f7523dffba1d2e7b3b2d0d1008d15b962e156dc))
* **api:** api update ([#178](https://github.com/conductor-is/conductor-python/issues/178)) ([55af15a](https://github.com/conductor-is/conductor-python/commit/55af15abe95640ba10fc8710d3adebf289db068e))
* **api:** api update ([#180](https://github.com/conductor-is/conductor-python/issues/180)) ([b642704](https://github.com/conductor-is/conductor-python/commit/b6427044c018fc7d6dcaa1dd030d6dd99e26a17d))
* **api:** manual updates ([#177](https://github.com/conductor-is/conductor-python/issues/177)) ([b1f9f41](https://github.com/conductor-is/conductor-python/commit/b1f9f415cdd9daf6aefd6909d028a840872d208e))
* **api:** manual updates ([#179](https://github.com/conductor-is/conductor-python/issues/179)) ([3f8b042](https://github.com/conductor-is/conductor-python/commit/3f8b042b26305874565c47649ed83f0ff1fa76fe))

## 0.1.0-alpha.20 (2024-10-29)

Full Changelog: [v0.1.0-alpha.19...v0.1.0-alpha.20](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.19...v0.1.0-alpha.20)

### Features

* **api:** api update ([#165](https://github.com/conductor-is/conductor-python/issues/165)) ([b0fc0ea](https://github.com/conductor-is/conductor-python/commit/b0fc0ea724c33073bb4f9d3e4f2dca2839437023))
* **api:** api update ([#167](https://github.com/conductor-is/conductor-python/issues/167)) ([4d2c696](https://github.com/conductor-is/conductor-python/commit/4d2c696f915580fb76e918ecf7361c8f28be47e3))
* **api:** api update ([#168](https://github.com/conductor-is/conductor-python/issues/168)) ([fb465fb](https://github.com/conductor-is/conductor-python/commit/fb465fb8daeaff3156f697351323b4654864a334))
* **api:** api update ([#169](https://github.com/conductor-is/conductor-python/issues/169)) ([58f5e6d](https://github.com/conductor-is/conductor-python/commit/58f5e6d8e21979a6b27fe9125cc45f7eb1e60533))

## 0.1.0-alpha.19 (2024-10-29)

Full Changelog: [v0.1.0-alpha.18...v0.1.0-alpha.19](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.18...v0.1.0-alpha.19)

### Features

* **api:** api update ([#147](https://github.com/conductor-is/conductor-python/issues/147)) ([67767e4](https://github.com/conductor-is/conductor-python/commit/67767e4e14599cf449c3354530e54b0bc35a2d39))
* **api:** api update ([#149](https://github.com/conductor-is/conductor-python/issues/149)) ([4389fb8](https://github.com/conductor-is/conductor-python/commit/4389fb83449cbc65440eb4a774da89a515c384e7))
* **api:** api update ([#150](https://github.com/conductor-is/conductor-python/issues/150)) ([85a6f4a](https://github.com/conductor-is/conductor-python/commit/85a6f4afd94dbd7e425a216a8e436723bc040ccf))
* **api:** api update ([#151](https://github.com/conductor-is/conductor-python/issues/151)) ([d04dbb4](https://github.com/conductor-is/conductor-python/commit/d04dbb439f93f569323b0182ffdce8de6b92a1de))
* **api:** api update ([#152](https://github.com/conductor-is/conductor-python/issues/152)) ([a83abbb](https://github.com/conductor-is/conductor-python/commit/a83abbbf65b35939327dc89d577d646046a2c6d1))
* **api:** api update ([#153](https://github.com/conductor-is/conductor-python/issues/153)) ([2eb29cf](https://github.com/conductor-is/conductor-python/commit/2eb29cf7d9f318d7fb0933702606056557c63330))
* **api:** api update ([#154](https://github.com/conductor-is/conductor-python/issues/154)) ([9fa3f46](https://github.com/conductor-is/conductor-python/commit/9fa3f46e18a0f293a0cb181999afa0722998804d))
* **api:** api update ([#155](https://github.com/conductor-is/conductor-python/issues/155)) ([1fce208](https://github.com/conductor-is/conductor-python/commit/1fce2080fc7c6b70197083f45e6cec60c818d3c4))
* **api:** api update ([#156](https://github.com/conductor-is/conductor-python/issues/156)) ([2354561](https://github.com/conductor-is/conductor-python/commit/2354561e9599619ca673282d0e97312dae5e235f))
* **api:** api update ([#157](https://github.com/conductor-is/conductor-python/issues/157)) ([6e47912](https://github.com/conductor-is/conductor-python/commit/6e47912257412e44fafd17b3c046327b9a71d8d0))
* **api:** api update ([#158](https://github.com/conductor-is/conductor-python/issues/158)) ([c4698eb](https://github.com/conductor-is/conductor-python/commit/c4698eb0911657ebc0501739875a2a374f4c7c07))
* **api:** api update ([#159](https://github.com/conductor-is/conductor-python/issues/159)) ([f20a401](https://github.com/conductor-is/conductor-python/commit/f20a401a2fe03a37114e767ac9f04768929ffab3))
* **api:** api update ([#160](https://github.com/conductor-is/conductor-python/issues/160)) ([6bd488d](https://github.com/conductor-is/conductor-python/commit/6bd488d458d79794ce2f92f7c7c582447099a71c))
* **api:** api update ([#161](https://github.com/conductor-is/conductor-python/issues/161)) ([e9819fe](https://github.com/conductor-is/conductor-python/commit/e9819fe8ee99def6f8abc582f41fead58102b166))
* **api:** api update ([#162](https://github.com/conductor-is/conductor-python/issues/162)) ([6a85379](https://github.com/conductor-is/conductor-python/commit/6a85379d12f05c36204ee76c79e6f2ce4e3f8ece))
* **api:** api update ([#163](https://github.com/conductor-is/conductor-python/issues/163)) ([61806c2](https://github.com/conductor-is/conductor-python/commit/61806c2248a288004a4da4ed19c10d0797c2f681))

## 0.1.0-alpha.18 (2024-10-25)

Full Changelog: [v0.1.0-alpha.17...v0.1.0-alpha.18](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.17...v0.1.0-alpha.18)

### Features

* **api:** api update ([#137](https://github.com/conductor-is/conductor-python/issues/137)) ([939b0ba](https://github.com/conductor-is/conductor-python/commit/939b0ba17571b6a2dd817769be3258087babd7a2))
* **api:** api update ([#139](https://github.com/conductor-is/conductor-python/issues/139)) ([7b0dcb6](https://github.com/conductor-is/conductor-python/commit/7b0dcb62035b4b4db51d0d8cead6587eceef64ad))
* **api:** api update ([#140](https://github.com/conductor-is/conductor-python/issues/140)) ([e5de8ce](https://github.com/conductor-is/conductor-python/commit/e5de8ce1e2bb37192d209f169376bd32d6899036))
* **api:** api update ([#141](https://github.com/conductor-is/conductor-python/issues/141)) ([0d94fa5](https://github.com/conductor-is/conductor-python/commit/0d94fa598c36d72b993ca9a9167b01a394bcab9f))
* **api:** api update ([#142](https://github.com/conductor-is/conductor-python/issues/142)) ([97b1df0](https://github.com/conductor-is/conductor-python/commit/97b1df095183b59b7efb11e6a936931e5921a545))
* **api:** api update ([#143](https://github.com/conductor-is/conductor-python/issues/143)) ([4ad6644](https://github.com/conductor-is/conductor-python/commit/4ad66446097bee2579993bb3240d136891797ae5))
* **api:** api update ([#144](https://github.com/conductor-is/conductor-python/issues/144)) ([2f8a5b1](https://github.com/conductor-is/conductor-python/commit/2f8a5b10e4d0cf1b167335867ac60ab1b971779e))
* **api:** api update ([#145](https://github.com/conductor-is/conductor-python/issues/145)) ([01cc429](https://github.com/conductor-is/conductor-python/commit/01cc429b5a66a3576de25df20e5a613135485e9c))

## 0.1.0-alpha.17 (2024-10-23)

Full Changelog: [v0.1.0-alpha.16...v0.1.0-alpha.17](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.16...v0.1.0-alpha.17)

### Features

* **api:** api update ([#128](https://github.com/conductor-is/conductor-python/issues/128)) ([86990d6](https://github.com/conductor-is/conductor-python/commit/86990d6adf623cc5479685b4358429cfa3436e12))
* **api:** api update ([#130](https://github.com/conductor-is/conductor-python/issues/130)) ([1eb7883](https://github.com/conductor-is/conductor-python/commit/1eb78836746812f5bf520c0454974d225ddc0265))
* **api:** api update ([#131](https://github.com/conductor-is/conductor-python/issues/131)) ([cbaa026](https://github.com/conductor-is/conductor-python/commit/cbaa0269d458162c0de44ad97fa4850691b84573))
* **api:** api update ([#132](https://github.com/conductor-is/conductor-python/issues/132)) ([77725bc](https://github.com/conductor-is/conductor-python/commit/77725bc55910e5d4c34e70b292149e1ba0b49555))
* **api:** api update ([#133](https://github.com/conductor-is/conductor-python/issues/133)) ([e22bf3f](https://github.com/conductor-is/conductor-python/commit/e22bf3f037feacf992b949d147fc6bed80d2e02e))
* **api:** api update ([#134](https://github.com/conductor-is/conductor-python/issues/134)) ([4e539c0](https://github.com/conductor-is/conductor-python/commit/4e539c02e75f8c922408ae5baca5b1aae5399efb))
* **api:** api update ([#135](https://github.com/conductor-is/conductor-python/issues/135)) ([63dbd3e](https://github.com/conductor-is/conductor-python/commit/63dbd3ec0751bd7d4ed13ca2cd1aabcf0453233d))

## 0.1.0-alpha.16 (2024-10-22)

Full Changelog: [v0.1.0-alpha.15...v0.1.0-alpha.16](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.15...v0.1.0-alpha.16)

### Features

* **api:** api update ([#122](https://github.com/conductor-is/conductor-python/issues/122)) ([5a046fe](https://github.com/conductor-is/conductor-python/commit/5a046fedea419981e6f5efc577e4f744a5fe9668))
* **api:** api update ([#124](https://github.com/conductor-is/conductor-python/issues/124)) ([f08e1d5](https://github.com/conductor-is/conductor-python/commit/f08e1d5df6e5a4ab7c00fb59c53c89bba0e6702e))
* **api:** api update ([#125](https://github.com/conductor-is/conductor-python/issues/125)) ([cefba23](https://github.com/conductor-is/conductor-python/commit/cefba23cd54badcbae9b6da3642a356164413578))
* **api:** api update ([#126](https://github.com/conductor-is/conductor-python/issues/126)) ([b5d109f](https://github.com/conductor-is/conductor-python/commit/b5d109f08852f32a15b1b954e704f848fabac6fa))

## 0.1.0-alpha.15 (2024-10-21)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** api update ([#114](https://github.com/conductor-is/conductor-python/issues/114)) ([81ceca3](https://github.com/conductor-is/conductor-python/commit/81ceca3a51deb4e0b661cdb25ac03d686cf5da17))
* **api:** api update ([#116](https://github.com/conductor-is/conductor-python/issues/116)) ([cca0685](https://github.com/conductor-is/conductor-python/commit/cca0685a54a4b1c10fde75ca906c89ffc2a0e77f))
* **api:** api update ([#117](https://github.com/conductor-is/conductor-python/issues/117)) ([3580042](https://github.com/conductor-is/conductor-python/commit/3580042d969fc1219b50cbb232cf87046802c8f7))
* **api:** api update ([#118](https://github.com/conductor-is/conductor-python/issues/118)) ([990e785](https://github.com/conductor-is/conductor-python/commit/990e78533545ddeb4761846f709200f9f192a305))
* **api:** api update ([#119](https://github.com/conductor-is/conductor-python/issues/119)) ([f8cd599](https://github.com/conductor-is/conductor-python/commit/f8cd59952c0d616987eae11e618cb16e190f3718))
* **api:** api update ([#120](https://github.com/conductor-is/conductor-python/issues/120)) ([5efe093](https://github.com/conductor-is/conductor-python/commit/5efe093f5212ac869cf40f4ec3373acd785802c9))

## 0.1.0-alpha.14 (2024-10-18)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** api update ([#108](https://github.com/conductor-is/conductor-python/issues/108)) ([edc26e0](https://github.com/conductor-is/conductor-python/commit/edc26e047ed8154337e2cff94c375df609d74450))
* **api:** api update ([#110](https://github.com/conductor-is/conductor-python/issues/110)) ([3747308](https://github.com/conductor-is/conductor-python/commit/374730855a2a4e33f56d0d2b358577526b842374))
* **api:** api update ([#111](https://github.com/conductor-is/conductor-python/issues/111)) ([fd32661](https://github.com/conductor-is/conductor-python/commit/fd32661d6314e409afc919118566efcf765e9bbf))
* **api:** api update ([#112](https://github.com/conductor-is/conductor-python/issues/112)) ([f119dad](https://github.com/conductor-is/conductor-python/commit/f119dadd355793e4492d8b4940862619e3676a70))

## 0.1.0-alpha.13 (2024-10-18)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* **api:** api update ([#101](https://github.com/conductor-is/conductor-python/issues/101)) ([af68f23](https://github.com/conductor-is/conductor-python/commit/af68f238e90d7e404bfb33464ba842b627f91e69))
* **api:** api update ([#103](https://github.com/conductor-is/conductor-python/issues/103)) ([47a729a](https://github.com/conductor-is/conductor-python/commit/47a729a7c462fb54f67a339e769c671cfcb27198))
* **api:** api update ([#104](https://github.com/conductor-is/conductor-python/issues/104)) ([dcaa703](https://github.com/conductor-is/conductor-python/commit/dcaa70341afb31882d48f5f73e783af49427990d))
* **api:** api update ([#105](https://github.com/conductor-is/conductor-python/issues/105)) ([1f77dd2](https://github.com/conductor-is/conductor-python/commit/1f77dd2649cc380b56e7985f96ab7c11bcfb5a26))
* **api:** api update ([#106](https://github.com/conductor-is/conductor-python/issues/106)) ([96c29f8](https://github.com/conductor-is/conductor-python/commit/96c29f8db72b2f290ac5525268deb20147b08b10))

## 0.1.0-alpha.12 (2024-10-17)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** api update ([#96](https://github.com/conductor-is/conductor-python/issues/96)) ([8aaa8b4](https://github.com/conductor-is/conductor-python/commit/8aaa8b46a7087e227bf0f4ac9872d9b296d02e94))
* **api:** api update ([#98](https://github.com/conductor-is/conductor-python/issues/98)) ([caf272a](https://github.com/conductor-is/conductor-python/commit/caf272a870faf890cd3eb754e63e3a23502966b5))
* **api:** api update ([#99](https://github.com/conductor-is/conductor-python/issues/99)) ([69373ee](https://github.com/conductor-is/conductor-python/commit/69373ee118fe9ba8430503a90466b6264877765c))

## 0.1.0-alpha.11 (2024-10-17)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** api update ([#92](https://github.com/conductor-is/conductor-python/issues/92)) ([b9c82e8](https://github.com/conductor-is/conductor-python/commit/b9c82e81841692cf7eaaf999ce6990c3478940cd))
* **api:** api update ([#94](https://github.com/conductor-is/conductor-python/issues/94)) ([b19f258](https://github.com/conductor-is/conductor-python/commit/b19f25850980fbcacbea7820ad9680335ccad20b))

## 0.1.0-alpha.10 (2024-10-16)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** api update ([#88](https://github.com/conductor-is/conductor-python/issues/88)) ([47528b8](https://github.com/conductor-is/conductor-python/commit/47528b8f9adc1bbcc9fa8546e706773bde3e53da))
* **api:** api update ([#90](https://github.com/conductor-is/conductor-python/issues/90)) ([041768f](https://github.com/conductor-is/conductor-python/commit/041768ffbfa1c651672714522c3f1fc9b3b41acd))

## 0.1.0-alpha.9 (2024-10-15)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** api update ([#85](https://github.com/conductor-is/conductor-python/issues/85)) ([25aadd4](https://github.com/conductor-is/conductor-python/commit/25aadd46efa964e8e67af36944117c948f4537da))

## 0.1.0-alpha.8 (2024-10-15)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** api update ([#74](https://github.com/conductor-is/conductor-python/issues/74)) ([d78d12d](https://github.com/conductor-is/conductor-python/commit/d78d12dd6e67e81ac9aeda72d19872e75d97f4ee))
* **api:** api update ([#76](https://github.com/conductor-is/conductor-python/issues/76)) ([d9707ac](https://github.com/conductor-is/conductor-python/commit/d9707ac5b91294665635024d522607cf5c292473))
* **api:** api update ([#77](https://github.com/conductor-is/conductor-python/issues/77)) ([ce621f4](https://github.com/conductor-is/conductor-python/commit/ce621f49a6359146915c4b6708b8ebee93dde0ac))
* **api:** api update ([#78](https://github.com/conductor-is/conductor-python/issues/78)) ([9bbbefc](https://github.com/conductor-is/conductor-python/commit/9bbbefcdef97e8cae0da28ca4e22d08d847e63b4))
* **api:** api update ([#79](https://github.com/conductor-is/conductor-python/issues/79)) ([2531f9a](https://github.com/conductor-is/conductor-python/commit/2531f9a7feb82f64061f1b936222905113af7568))
* **api:** api update ([#80](https://github.com/conductor-is/conductor-python/issues/80)) ([4d9bcd4](https://github.com/conductor-is/conductor-python/commit/4d9bcd4919853a43bc7eb79637597d885f918819))
* **api:** api update ([#81](https://github.com/conductor-is/conductor-python/issues/81)) ([b68a9f0](https://github.com/conductor-is/conductor-python/commit/b68a9f0dacdb62f66eb272a1de09e0073afafa34))
* **api:** api update ([#82](https://github.com/conductor-is/conductor-python/issues/82)) ([3088198](https://github.com/conductor-is/conductor-python/commit/308819821a26c5a1af87d7a096098b4adc56a72a))
* **api:** api update ([#83](https://github.com/conductor-is/conductor-python/issues/83)) ([5e412c9](https://github.com/conductor-is/conductor-python/commit/5e412c9ba388aca61a2cfa8b2709d75779664d94))

## 0.1.0-alpha.7 (2024-10-13)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** api update ([#64](https://github.com/conductor-is/conductor-python/issues/64)) ([be0d706](https://github.com/conductor-is/conductor-python/commit/be0d7065ee51175487b8005e62d9d06f7a5ecbfc))
* **api:** api update ([#66](https://github.com/conductor-is/conductor-python/issues/66)) ([13c840a](https://github.com/conductor-is/conductor-python/commit/13c840a629c0d7a50456ecf47b274153f4faa0ab))
* **api:** api update ([#67](https://github.com/conductor-is/conductor-python/issues/67)) ([54e5574](https://github.com/conductor-is/conductor-python/commit/54e5574c0c878db84febda4bf57093cf61fccb7f))
* **api:** api update ([#68](https://github.com/conductor-is/conductor-python/issues/68)) ([d6b7732](https://github.com/conductor-is/conductor-python/commit/d6b77326ffe72049bf4ca9e79d137bf7d5236fee))
* **api:** api update ([#69](https://github.com/conductor-is/conductor-python/issues/69)) ([6f92519](https://github.com/conductor-is/conductor-python/commit/6f92519a728c9630178ed641881738afce8e91ae))
* **api:** api update ([#70](https://github.com/conductor-is/conductor-python/issues/70)) ([157b28a](https://github.com/conductor-is/conductor-python/commit/157b28a93fb9e3c540f2fc68adab6b7bba34b975))

## 0.1.0-alpha.6 (2024-10-11)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([#54](https://github.com/conductor-is/conductor-python/issues/54)) ([eb97202](https://github.com/conductor-is/conductor-python/commit/eb97202f7585b7285531c59684d27bede40ef65a))
* **api:** api update ([#55](https://github.com/conductor-is/conductor-python/issues/55)) ([a11a233](https://github.com/conductor-is/conductor-python/commit/a11a23325b622b55bba42da190dca9fb1abd3c01))
* **api:** api update ([#56](https://github.com/conductor-is/conductor-python/issues/56)) ([d75fe5c](https://github.com/conductor-is/conductor-python/commit/d75fe5c0182c74e31e8caf66ecf4272a0d0855a8))
* **api:** api update ([#57](https://github.com/conductor-is/conductor-python/issues/57)) ([028221b](https://github.com/conductor-is/conductor-python/commit/028221bd3fafe30ac1748211f25ad041143d43b7))
* **api:** api update ([#58](https://github.com/conductor-is/conductor-python/issues/58)) ([3da87a3](https://github.com/conductor-is/conductor-python/commit/3da87a3896b069ba2b9caa91aed12ca7ca0becec))
* **api:** api update ([#59](https://github.com/conductor-is/conductor-python/issues/59)) ([72e66d8](https://github.com/conductor-is/conductor-python/commit/72e66d86398016171d5db70faf4d3c00eb19a029))
* **api:** api update ([#60](https://github.com/conductor-is/conductor-python/issues/60)) ([9e1cfc5](https://github.com/conductor-is/conductor-python/commit/9e1cfc5883d1f5bb39ffa296589e3ffc8f60ca91))
* **api:** api update ([#61](https://github.com/conductor-is/conductor-python/issues/61)) ([b8500c9](https://github.com/conductor-is/conductor-python/commit/b8500c9a5f47d7d24506bf5298e6ef5888e2501a))
* **api:** manual updates ([#48](https://github.com/conductor-is/conductor-python/issues/48)) ([937a294](https://github.com/conductor-is/conductor-python/commit/937a29406616ac3b157a40cf57afb5b2fa2d4eb1))
* **api:** OpenAPI spec update via Stainless API ([#44](https://github.com/conductor-is/conductor-python/issues/44)) ([833e15c](https://github.com/conductor-is/conductor-python/commit/833e15cc216753635a4b9b675a55933207605952))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/conductor-is/conductor-python/issues/49)) ([1acf56d](https://github.com/conductor-is/conductor-python/commit/1acf56d3d3d6227597c42d4aca3880149c0801a6))
* **api:** OpenAPI spec update via Stainless API ([#50](https://github.com/conductor-is/conductor-python/issues/50)) ([95b0cf7](https://github.com/conductor-is/conductor-python/commit/95b0cf7a5c82de9fecb8f602b0fe14a988c817a2))
* **api:** OpenAPI spec update via Stainless API ([#51](https://github.com/conductor-is/conductor-python/issues/51)) ([45d59e1](https://github.com/conductor-is/conductor-python/commit/45d59e15a9e26e6f3beacf901e539825944d306f))
* **api:** OpenAPI spec update via Stainless API ([#52](https://github.com/conductor-is/conductor-python/issues/52)) ([d8b2520](https://github.com/conductor-is/conductor-python/commit/d8b2520898dcc42d284545cacb9fef304aa8b47f))
* **api:** OpenAPI spec update via Stainless API ([#53](https://github.com/conductor-is/conductor-python/issues/53)) ([8d18a81](https://github.com/conductor-is/conductor-python/commit/8d18a81da2d72c8320cf250aa6d90d9868757a5e))


### Bug Fixes

* **client:** avoid OverflowError with very large retry counts ([#46](https://github.com/conductor-is/conductor-python/issues/46)) ([169b02c](https://github.com/conductor-is/conductor-python/commit/169b02cab2670283bcb4fdca71f97273e25dde82))


### Chores

* add repr to PageInfo class ([#47](https://github.com/conductor-is/conductor-python/issues/47)) ([de0c019](https://github.com/conductor-is/conductor-python/commit/de0c0191d7c082bef2050a5225bd325b46233068))

## 0.1.0-alpha.5 (2024-10-06)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([#38](https://github.com/conductor-is/conductor-python/issues/38)) ([2ea197b](https://github.com/conductor-is/conductor-python/commit/2ea197ba93ee128b07697900af32d1eadd959fc9))


### Chores

* **internal:** add support for parsing bool response content ([#42](https://github.com/conductor-is/conductor-python/issues/42)) ([b59e831](https://github.com/conductor-is/conductor-python/commit/b59e831d1a32f4f23f392ec634f2154fba1c06b5))
* **internal:** codegen related update ([#40](https://github.com/conductor-is/conductor-python/issues/40)) ([f759a7a](https://github.com/conductor-is/conductor-python/commit/f759a7a89512509169e0f8ded4bd7d2ce3e2d147))
* **internal:** codegen related update ([#41](https://github.com/conductor-is/conductor-python/issues/41)) ([3e863ee](https://github.com/conductor-is/conductor-python/commit/3e863ee5cf5418a95ab884b17d5bc1cb511b6aa0))

## 0.1.0-alpha.4 (2024-09-30)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([#27](https://github.com/conductor-is/conductor-python/issues/27)) ([889eca4](https://github.com/conductor-is/conductor-python/commit/889eca4a6fc284f5ef954a972e88cd8640b82b22))
* **api:** update via SDK Studio ([#29](https://github.com/conductor-is/conductor-python/issues/29)) ([1b59254](https://github.com/conductor-is/conductor-python/commit/1b592549e266594ca0abb7bcdb104be7f1cd7ebb))
* **api:** update via SDK Studio ([#30](https://github.com/conductor-is/conductor-python/issues/30)) ([fa7c51a](https://github.com/conductor-is/conductor-python/commit/fa7c51ad61d34a2fe9e26925a1d7cf26990d41df))
* **api:** update via SDK Studio ([#33](https://github.com/conductor-is/conductor-python/issues/33)) ([7f0f5ee](https://github.com/conductor-is/conductor-python/commit/7f0f5ee693cb0c0a90b652e8ed9a8e1228f147df))
* **client:** send retry count header ([#32](https://github.com/conductor-is/conductor-python/issues/32)) ([10faf81](https://github.com/conductor-is/conductor-python/commit/10faf813124c37b08113d7de41f3920bd1886a0c))


### Bug Fixes

* **client:** handle domains with underscores ([#31](https://github.com/conductor-is/conductor-python/issues/31)) ([8e750e1](https://github.com/conductor-is/conductor-python/commit/8e750e1a6799fea10221d09e7fc38fb2bfe9163f))


### Chores

* **internal:** codegen related update ([#35](https://github.com/conductor-is/conductor-python/issues/35)) ([52c3970](https://github.com/conductor-is/conductor-python/commit/52c3970e956893a39e7bba9399538b7646901aca))
* **internal:** codegen related update ([#36](https://github.com/conductor-is/conductor-python/issues/36)) ([31d4ef4](https://github.com/conductor-is/conductor-python/commit/31d4ef47f4da3f0f508d8f50a1b164ea1ce194d2))
* **internal:** update pydantic v1 compat helpers ([#34](https://github.com/conductor-is/conductor-python/issues/34)) ([68fffdb](https://github.com/conductor-is/conductor-python/commit/68fffdb97d5f765d59df9588fcb1577fd569f608))

## 0.1.0-alpha.3 (2024-09-18)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([#16](https://github.com/conductor-is/conductor-python/issues/16)) ([db50bae](https://github.com/conductor-is/conductor-python/commit/db50bae0dcd000a0a4697a8042327ad9ad7f05b4))
* **api:** update via SDK Studio ([#18](https://github.com/conductor-is/conductor-python/issues/18)) ([b18af59](https://github.com/conductor-is/conductor-python/commit/b18af595f682ccf653f82d3cba776b57171547e1))
* **api:** update via SDK Studio ([#19](https://github.com/conductor-is/conductor-python/issues/19)) ([83aeedd](https://github.com/conductor-is/conductor-python/commit/83aeedd330ff2a890322e32b64a98862d6df0c9b))
* **api:** update via SDK Studio ([#22](https://github.com/conductor-is/conductor-python/issues/22)) ([d820537](https://github.com/conductor-is/conductor-python/commit/d82053740ad57792048b477ee3b92dc78e1e7fc3))
* **api:** update via SDK Studio ([#23](https://github.com/conductor-is/conductor-python/issues/23)) ([26f5d61](https://github.com/conductor-is/conductor-python/commit/26f5d61f657cddc5bb1d9ae386d7477872e73f32))
* **api:** update via SDK Studio ([#24](https://github.com/conductor-is/conductor-python/issues/24)) ([820c8c3](https://github.com/conductor-is/conductor-python/commit/820c8c384286e3a7c79a40832a0426f7eb7302c4))
* **api:** update via SDK Studio ([#25](https://github.com/conductor-is/conductor-python/issues/25)) ([d1fc04b](https://github.com/conductor-is/conductor-python/commit/d1fc04b036c23c03316cf91cdc4d897959458ca9))


### Chores

* add docstrings to raw response properties ([#13](https://github.com/conductor-is/conductor-python/issues/13)) ([6300c96](https://github.com/conductor-is/conductor-python/commit/6300c9613a7a056cc2ad21a401730a148a59da4a))
* **internal:** bump pyright / mypy version ([#21](https://github.com/conductor-is/conductor-python/issues/21)) ([a6e8897](https://github.com/conductor-is/conductor-python/commit/a6e8897535da4f3a396badb4c3fe34455c32beb6))
* **internal:** bump ruff ([#20](https://github.com/conductor-is/conductor-python/issues/20)) ([9e245df](https://github.com/conductor-is/conductor-python/commit/9e245df647a688ede26f8d79e3c42612cd5a8766))


### Documentation

* **readme:** add section on determining installed version ([#14](https://github.com/conductor-is/conductor-python/issues/14)) ([b7c9f8b](https://github.com/conductor-is/conductor-python/commit/b7c9f8bb1f96d2c256a229fd3321f4ce7def744e))
* update CONTRIBUTING.md ([#17](https://github.com/conductor-is/conductor-python/issues/17)) ([96cb918](https://github.com/conductor-is/conductor-python/commit/96cb918d7393283736cd6e29b8b0b034cd81aece))

## 0.1.0-alpha.2 (2024-09-08)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/conductor-is/conductor-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/conductor-is/conductor-python/issues/11)) ([fb69258](https://github.com/conductor-is/conductor-python/commit/fb69258a1df4e3cee8fa6ebe056b0336724b2c1f))
* **api:** update via SDK Studio ([#7](https://github.com/conductor-is/conductor-python/issues/7)) ([6708001](https://github.com/conductor-is/conductor-python/commit/670800117c6222c8ee30f85f2c90f7e114b73302))


### Chores

* pyproject.toml formatting changes ([#9](https://github.com/conductor-is/conductor-python/issues/9)) ([ceac058](https://github.com/conductor-is/conductor-python/commit/ceac0582eb3ebb352bbf9ce26e930d40eb9b39f6))

## 0.1.0-alpha.1 (2024-09-02)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/conductor-is/conductor-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([b6472f6](https://github.com/conductor-is/conductor-python/commit/b6472f626e01f0db7d43f7877bf2f5e2ecf5fddb))
* **api:** update via SDK Studio ([#4](https://github.com/conductor-is/conductor-python/issues/4)) ([c211314](https://github.com/conductor-is/conductor-python/commit/c2113146925f252addb52f99a25a0ac0e873597a))
* **api:** update via SDK Studio ([#5](https://github.com/conductor-is/conductor-python/issues/5)) ([253d78c](https://github.com/conductor-is/conductor-python/commit/253d78c50259ec7e1cde2d66a6cfcc137252bc0b))


### Chores

* go live ([#1](https://github.com/conductor-is/conductor-python/issues/1)) ([4be56ce](https://github.com/conductor-is/conductor-python/commit/4be56ce217400f0013c503ccdf82f96b0abe35c4))
* update SDK settings ([#3](https://github.com/conductor-is/conductor-python/issues/3)) ([f042384](https://github.com/conductor-is/conductor-python/commit/f04238468a1f22471e26f5bcd8b3e97a59ca4af9))
